let mapView;
let userMarker;
let stationSearch;
let lineSearch;
let stationMarker;
let polyline;

function updateUserMarker(lon, lat) {
  // let ret = wgs84togcj02(lon, lat);
  // let longitude = ret[0];
  // let latitude = ret[1];
  return userMarker.setPosition(new AMap.LngLat(lon, lat));
}

function setMapCenter(lon, lat) {
  return mapView.setCenter(new AMap.LngLat(lon, lat));
}

function setZoomAndCenter(zoom, lon, lat) {
  if (lat != 0 && lon != 0) {
    // let ret = wgs84togcj02(lon, lat);
    // let longitude = ret[0];
    // let latitude = ret[1];
    return mapView.setZoomAndCenter(zoom, new AMap.LngLat(lon, lat));
  }
}

function setCityId(id) {
  app.cityId = id;
  stationSearch.setCity(app.cityId);
  lineSearch.setCity(app.cityId);
  for (let i = 0; i < app.cityData.length; i++) {
    if (app.cityId == app.cityData[i].id) {
      app.cityName = app.cityData[i].name;
    }
  }
}

var app = new Vue({
  el: "#app",
  data: {
    trafficLayer: null,
    showTrafficLayer: false,
    buildingsLayer: null,
    satelliteLayer: null,
    roadNetLayer: null,
    mapType: 0,
    cityData: getCityList(),
    cityId: "",
    cityName: "",
    inputType: 0,
    stationKeyword: "",
    lineKeyword: "",
    stationList: [],
    lineList: [],
  },
  methods: {
    onStationInputChange() {
      if (app.stationKeyword == "") {
        app.stationList = [];
        mapView.remove(stationMarker);
      }
    },
    onLineInputChange() {
      if (app.lineKeyword == "") {
        app.lineList = [];
        mapView.clearMap();
      }
    },
    onStationSearch() {
      stationSearch.search(app.stationKeyword, function (status, result) {
        if (status == "complete") {
          console.log(result.stationInfo);
          app.stationList = result.stationInfo;
          window.location.href = "beido://searchStation";
        } else if (status == "no_data") {
          app.stationLis = [];
          window.location.href = "beido://noStationData";
        } else if (status == "error") {
          console.log("stationKeyword error");
        }
      });
    },
    onLineSearch() {
      lineSearch.search(app.lineKeyword, function (status, result) {
        console.log(status, result);
        if (status == "complete") {
          console.log(result.lineInfo);
          app.lineList = result.lineInfo;
          window.location.href = "beido://searchLine";
        } else if (status == "no_data") {
          app.lineList = [];
          window.location.href = "beido://noLineData";
        } else if (status == "error") {
          console.log("lineSearch error");
        }
      });
    },
    onStationItemClick(item) {
      app.stationList = [];
      if (stationMarker) {
        mapView.remove(stationMarker);
      }
      stationMarker = new AMap.Marker({
        position: new AMap.LngLat(item.location.lng, item.location.lat),
        offset: new AMap.Pixel(0, -20),
        icon: "img/marker.png",
        anchor: "center",
      });
      mapView.add(stationMarker);
      stationMarker.info = new AMap.InfoWindow({
        content: item.name,
        offset: new AMap.Pixel(0, -45),
      });
      stationMarker.info.open(mapView, item.location);
      mapView.setCenter(item.location);
    },
    onLineItemClick(item) {
      app.lineList = [];
      if (polyline) {
        mapView.remove(polyline);
        mapView.clearMap();
      }
      polyline = new AMap.Polyline({
        path: item.path,
        strokeWeight: 5, //线条宽度
        strokeColor: "blue", //线条颜色
        lineJoin: "round", //折线拐点连接处样式
      });
      mapView.add(polyline);
      mapView.setBounds(item.bounds, true, [100, 100, 50, 50]);

      if (item.via_stops && item.via_stops.length > 0) {
        for (let i = 0; i < item.via_stops.length; i++) {
          if (i == 0) {
            var marker = new AMap.Marker({
              icon: new AMap.Icon({
                image: "img/startMarker.png",
                size: new AMap.Size(30, 40),
                imageSize: new AMap.Size(30, 40),
              }),
              offset: new AMap.Pixel(-15, -35),
              position: item.via_stops[i].location,
              map: mapView,
            });
            //构造 marker 的信息窗体
            marker.info = new AMap.InfoWindow({
              content: item.via_stops[i].name,
              offset: new AMap.Pixel(0, -25),
            });
            marker.info.open(mapView, item.via_stops[i].location);
          } else if (i == item.via_stops.length - 1) {
            var marker = new AMap.Marker({
              icon: new AMap.Icon({
                image: "img/endMarker.png",
                size: new AMap.Size(30, 40),
                imageSize: new AMap.Size(30, 40),
              }),
              offset: new AMap.Pixel(-15, -35),
              position: item.via_stops[i].location,
              map: mapView,
            });
            marker.info = new AMap.InfoWindow({
              content: item.via_stops[i].name,
              offset: new AMap.Pixel(0, -25),
            });
            marker.on("click", function (e) {
              e.target.info.open(mapView, e.target.getPosition());
            });
          } else {
            var marker = new AMap.Marker({
              icon: new AMap.Icon({
                image: "img/stops.png",
                size: new AMap.Size(16, 16),
                imageSize: new AMap.Size(16, 16),
              }),
              offset: new AMap.Pixel(-8, -8),
              position: item.via_stops[i].location,
              map: mapView,
            });
            marker.info = new AMap.InfoWindow({
              content: item.via_stops[i].name,
              offset: new AMap.Pixel(0, -8),
            });
            marker.on("click", function (e) {
              e.target.info.open(mapView, e.target.getPosition());
            });
          }
        }
      }
    },
    onZoomInClick() {
      mapView.zoomIn();
    },
    onZoomOutClick() {
      mapView.zoomOut();
    },
    onTrafficButtonClick() {
      if (app.showTrafficLayer) {
        app.trafficLayer.hide();
        app.showTrafficLayer = false;
      } else {
        app.trafficLayer.show();
        app.showTrafficLayer = true;
      }
    },
    onLocationButtonClick() {
      window.location.href = "beido://locationButtonClick";
    },
    onMapTypeButtonClick() {
      if (app.mapType == 0) {
        app.satelliteLayer.show();
        app.mapType = 1;
      } else if (app.mapType == 1) {
        app.satelliteLayer.hide();
        app.mapType = 0;
      }
      var url = "beido://mapType=" + app.mapType;
      window.location.href = url;
    },
    onMenuButtonClick() {
      window.location.href = "beido://goMenuPage";
    },
    onInputClick() {
      var lng = userMarker.getPosition().lng;
      var lat = userMarker.getPosition().lat;
      window.location.href = "beido://goSearchPage?lng=" + lng + "&lat=" + lat;
    },
    onChangeCityClick() {
      window.location.href = "beido://goCityListPage";
    },
    onStationButtonClick() {
      app.stationList = [];
      app.lineList = [];
      app.stationKeyword = "";
      if (stationMarker) {
        mapView.remove(stationMarker);
        mapView.clearInfoWindow();
      }
      if (app.inputType == 1) {
        app.inputType = 0;
      } else {
        app.inputType = 1;
      }
    },
    onLineButtonClick() {
      app.stationList = [];
      app.lineList = [];
      app.lineKeyword = "";
      if (stationMarker) {
        mapView.remove(stationMarker);
        mapView.clearInfoWindow();
      }
      if (polyline) {
        mapView.clearMap();
      }
      if (app.inputType == 2) {
        app.inputType = 0;
      } else {
        app.inputType = 2;
      }
    },
    //获取get参数的方法
    getQueryString(name) {
      var reg = new RegExp("(^|&)" + name + "=([^&]*)(&|$)");
      var r = window.location.search.substr(1).match(reg);
      if (r != null) return unescape(r[2]);
      return null;
    },
  },
});

app.cityId = app.getQueryString("id");

for (let i = 0; i < app.cityData.length; i++) {
  if (app.cityId == app.cityData[i].id) {
    app.cityName = app.cityData[i].name;
  }
}

//初始化地图
AMapLoader.load({
  key: "7b2391e8811341af41be20b5e43ebfc5",
  version: "2.0",
})
  .then((AMap) => {
    mapView = new AMap.Map("mapView", {
      center: [116.397503, 39.907934],
      zoom: 15,
      animateEnable: false,
      viewMode: "3D",
    });

    AMap.plugin("AMap.Marker", function () {
      //用户位置Marker
      userMarker = new AMap.Marker({
        position: new AMap.LngLat(116.397503, 39.907934),
        offset: new AMap.Pixel(0, 0),
        icon: "img/user_location.png",
        anchor: "center",
      });
      mapView.add(userMarker);
    });

    AMap.plugin(["AMap.StationSearch"], function () {
      stationSearch = new AMap.StationSearch({
        pageIndex: 1,
        pageSize: 20,
        city: app.cityId, //限定查询城市，可以是城市名（中文/中文全拼）、城市编码
      });
    });

    //实例化公交线路查询插件
    AMap.plugin(["AMap.LineSearch"], function () {
      lineSearch = new AMap.LineSearch({
        pageIndex: 1, //页码，默认值为1
        pageSize: 20, //单页显示结果条数，默认值为20，最大值为50
        city: app.cityId, //限定查询城市，可以是城市名（中文/中文全拼）、城市编码
        extensions: "all", //是否返回公交线路详细信息，默认值为 "base"
      });
    });

    //实时路况图层
    app.trafficLayer = new AMap.TileLayer.Traffic({
      map: mapView,
      zIndex: 11,
    });
    app.trafficLayer.hide();

    //卫星图层
    app.satelliteLayer = new AMap.TileLayer.Satellite({
      map: mapView,
      zIndex: 10,
    });
    app.satelliteLayer.hide();

    //路网图层
    app.roadNetLayer = new AMap.TileLayer.RoadNet({
      map: mapView,
      zIndex: 10,
    });
    app.roadNetLayer.hide();

    // 楼块图层
    app.buildingsLayer = new AMap.Buildings({
      map: mapView,
      zIndex: 10,
      heightFactor: 2,
    });
    app.buildingsLayer.hide();
  })
  .catch((e) => {
    console.error(e);
  });
function onLoad() {}
