let mapView;
let userMarker;
let transfer;

function updateUserMarker(lon, lat) {
  // let ret = wgs84togcj02(lon, lat);
  // let longitude = ret[0];
  // let latitude = ret[1];
  return userMarker.setPosition(new AMap.LngLat(lon, lat));
}

function setMapCenter(lon, lat) {
  return mapView.setCenter(new AMap.LngLat(lon, lat));
}

function setZoomAndCenter(zoom, lon, lat) {
  if (lat != 0 && lon != 0) {
    // let ret = wgs84togcj02(lon, lat);
    // let longitude = ret[0];
    // let latitude = ret[1];
    return mapView.setZoomAndCenter(zoom, new AMap.LngLat(lon, lat));
  }
}

function setStartPoi(lon, lat, name) {
  app.setStartPoi(lon, lat, name);
}

function setEndPoi(lon, lat, name) {
  app.setEndPoi(lon, lat, name);
}

function setCityId(id) {
  app.cityId = id;
}

const app = new Vue({
  el: "#app",
  data: {
    trafficLayer: null,
    showTrafficLayer: false,
    buildingsLayer: null,
    satelliteLayer: null,
    roadNetLayer: null,
    mapType: 0,
    cityData: getCityList(),
    cityId: "",
    startPoiName: "",
    startPosition: {},
    endPoiName: "",
    endPosition: {},
    policy: 0,
    policyList: [
      { id: 0, name: "最快捷" },
      { id: 1, name: "最经济" },
      { id: 2, name: "最少换乘" },
      { id: 3, name: "最少步行" },
      { id: 5, name: "不乘地铁" },
    ],
    totalTime: "",
    totalDistance: "",
    walkingDistance: "",
    totalCoast: "",
    totalStops: "",
    taxiFee: "",
    showList: false,
    segments: {},
  },
  methods: {
    onChangeListButtonClick() {
      let that = this;
      that.showList = true;
    },
    onChangeMapButtonClick() {
      let that = this;
      that.showList = false;
    },
    onPolicyItemClick(item) {
      let that = this;
      that.policy = item.id;
      if (
        that.startPoiName &&
        that.startPoiName.length != 0 &&
        that.endPoiName &&
        that.endPoiName.length != 0
      ) {
        that.startRoute();
      }
    },
    setStartPoi(lon, lat, name) {
      let that = this;
      that.startPoiName = name;
      if (that.startPoiName == "当前位置") {
        let ret = wgs84togcj02(lon, lat);
        that.startPosition = new AMap.LngLat(ret[0], ret[1]);
      } else {
        that.startPosition = new AMap.LngLat(lon, lat);
      }
      if (that.endPoiName && that.endPoiName.length != 0) {
        that.startRoute();
      }
    },
    setEndPoi(lon, lat, name) {
      let that = this;
      that.endPoiName = name;
      that.endPosition = new AMap.LngLat(lon, lat);
      if (that.startPoiName && that.startPoiName.length != 0) {
        that.startRoute();
      }
    },
    startRoute() {
      let that = this;
      that.totalTime = "";
      that.totalDistance = "";
      that.walkingDistance = "";
      that.totalCoast = "";
      that.totalStops = "";
      that.taxiFee = "";

      AMap.plugin("AMap.Transfer", function () {
        if (!transfer) {
          transfer = new AMap.Transfer({
            city: that.cityId,
            map: mapView,
            policy: that.policy,
          });
        }
        transfer.clear();
        transfer.setPolicy(that.policy);
        //获取起终点规划线路
        transfer.search(
          that.startPosition,
          that.endPosition,
          function (status, result) {
            if (status === "complete") {
              //status：complete 表示查询成功，no_data 为查询无结果，error 代表查询错误
              console.log(result);
              if (result.plans && result.plans.length > 0) {
                that.totalTime = that.formatTime(result.plans[0].time);
                that.totalDistance = that.formatDistance(
                  result.plans[0].transit_distance +
                    result.plans[0].walking_distance
                );
                that.walkingDistance = that.formatDistance(
                  result.plans[0].walking_distance
                );
                that.taxiFee = result.taxi_cost + "元";
                that.totalCoast = result.plans[0].cost + "元";
                that.totalStops = that.calcStop(result.plans[0]);
                that.segments = result.plans[0].segments;
              }
            } else {
              console.log("获取驾车数据失败：" + result);
            }
          }
        );
      });
    },
    calcStop(plan) {
      let stopCount = 0;
      let segments = plan.segments;
      if (segments && segments.length > 0) {
        for (let i = 0; i < segments.length; i++) {
          if (segments[i].transit && segments[i].transit.via_num != undefined) {
            stopCount += segments[i].transit.via_num + 1;
          }
        }
      }
      return stopCount + "站";
    },
    formatTime(time) {
      if (time < 60) {
        return time + "秒";
      } else if (time < 60 * 60) {
        return Math.floor(time / 60) + "分钟";
      } else {
        let hour = Math.floor(time / 3600);
        let minute = Math.floor((time % 3600) / 60);
        return hour + "小时" + minute + "分钟";
      }
    },
    formatDistance(distance) {
      if (distance < 1000) {
        return Math.floor(distance) + "米";
      } else if (distance < 100 * 1000) {
        return (distance / 1000).toFixed(1) + "公里";
      } else {
        return Math.floor(distance / 1000) + "公里";
      }
    },
    onZoomInClick() {
      mapView.zoomIn();
    },
    onZoomOutClick() {
      mapView.zoomOut();
    },
    onTrafficButtonClick() {
      let that = this;
      if (that.showTrafficLayer) {
        that.trafficLayer.hide();
        that.showTrafficLayer = false;
      } else {
        that.trafficLayer.show();
        that.showTrafficLayer = true;
      }
    },
    onLocationButtonClick() {
      window.location.href = "beido://locationButtonClick";
    },
    onChangeCityClick() {
      window.location.href = "beido://goCityListPage";
    },
    onStartViewClick() {
      window.location.href = "beido://setStartClick";
    },
    onEndViewClick() {
      window.location.href = "beido://setEndClick";
    },
    onMapTypeButtonClick() {
      let that = this;
      if (that.mapType == 0) {
        that.satelliteLayer.show();
        that.mapType = 1;
      } else if (that.mapType == 1) {
        that.satelliteLayer.hide();
        that.mapType = 0;
      }
      var url = "beido://mapType=" + that.mapType;
      window.location.href = url;
    },
    onInputClick() {
      var lng = userMarker.getPosition().lng;
      var lat = userMarker.getPosition().lat;
      window.location.href = "beido://goSearchPage?lng=" + lng + "&lat=" + lat;
    },

    //获取get参数的方法
    getQueryString(name) {
      var reg = new RegExp("(^|&)" + name + "=([^&]*)(&|$)");
      var r = window.location.search.substr(1).match(reg);
      if (r != null) return unescape(r[2]);
      return null;
    },
  },
});

app.cityId = app.getQueryString("id");

//初始化地图
AMapLoader.load({
  key: "7b2391e8811341af41be20b5e43ebfc5",
  version: "2.0",
})
  .then((AMap) => {
    mapView = new AMap.Map("mapView", {
      center: [116.397503, 39.907934],
      zoom: 15,
      animateEnable: false,
      viewMode: "3D",
    });

    AMap.plugin("AMap.Marker", function () {
      //用户位置Marker
      userMarker = new AMap.Marker({
        position: new AMap.LngLat(116.397503, 39.907934),
        offset: new AMap.Pixel(0, 0),
        icon: "img/user_location.png",
        anchor: "center",
      });
      mapView.add(userMarker);
    });

    if (
      app.startPoiName &&
      app.startPoiName.length != 0 &&
      app.endPoiName &&
      app.endPoiName.length != 0
    ) {
      app.startRoute();
    }

    //实时路况图层
    app.trafficLayer = new AMap.TileLayer.Traffic({
      map: mapView,
      zIndex: 11,
    });
    app.trafficLayer.hide();

    //卫星图层
    app.satelliteLayer = new AMap.TileLayer.Satellite({
      map: mapView,
      zIndex: 10,
    });
    app.satelliteLayer.hide();

    //路网图层
    app.roadNetLayer = new AMap.TileLayer.RoadNet({
      map: mapView,
      zIndex: 10,
    });
    app.roadNetLayer.hide();

    // 楼块图层
    app.buildingsLayer = new AMap.Buildings({
      map: mapView,
      zIndex: 10,
      heightFactor: 2,
    });
    app.buildingsLayer.hide();
  })
  .catch((e) => {
    console.error(e);
  });

function onLoad() {}
